@@ -28,7 +28,7 @@ def has_permission(request):
     hashedToken = hash_token(token, limitedAccessToken.salt)
     return hashedToken == limitedAccessToken.hash
 
-def save_pre_key_bundle(request):
+def save_pre_key_bundle(request, user):
     """
     A user must upload their PreKeyBundle at registration time. Before uploading their PreKeyBundle, they need to verify
     their phone number, and get their LimitedAccessToken.
@@ -36,7 +36,6 @@ def save_pre_key_bundle(request):
     if not has_permission(request):
         return False
     data = request.data
-    user = User.objects.get(phone=request.data['phone'])
     identityKey = data["identityKey"]
     signedPreKey = data["signedPreKey"]
     preKeys = data["preKeys"]
